@@ -5,6 +5,7 @@ import bisect
 import concurrent.futures
 import gc
 import itertools
+import json
 import logging
 import multiprocessing
 import os
@@ -24,8 +25,10 @@ from uuid import uuid4
 
 from upathlib import LocalUpath, Upath  # type: ignore
 from upathlib.serializer import (
-    ByteSerializer, PickleSerializer, CompressedPickleSerializer,
-    JsonByteSerializer, OrjsonSerializer, CompressedOrjsonSerializer,
+    ByteSerializer, _loads,
+    ZJsonSerializer, ZstdJsonSerializer,
+    PickleSerializer, ZPickleSerializer, ZstdPickleSerializer,
+    OrjsonSerializer, ZOrjsonSerializer, ZstdOrjsonSerializer,
 )
 
 
@@ -181,9 +184,7 @@ class Biglist(Sequence):
     Data access is optimized for iteration, whereas random access
     (via index or slice) is less efficient, and assumed to be rare.
     '''
-    registered_storage_formats = {
-        'pickle': PickleSerializer,
-    }
+    registered_storage_formats = {}
 
     DEFAULT_STORAGE_FORMAT = 'pickle'
 
@@ -320,11 +321,12 @@ class Biglist(Sequence):
 
         if storage_format is None:
             storage_format = cls.DEFAULT_STORAGE_FORMAT
+            obj.info['storage_format'] = storage_format
         else:
             if storage_format.replace('-', '_') not in cls.registered_storage_formats:
                 raise ValueError(
                     f"invalid value of `storage_format`: '{storage_format}'")
-        obj.info['storage_format'] = storage_format.replace('-', '_')
+            obj.info['storage_format'] = storage_format.replace('-', '_')
         obj.info['storage_version'] = 0
         # version 0 designator introduced on 2022/3/8
         obj._info_file.write_json(obj.info, overwrite=False)
@@ -391,7 +393,7 @@ class Biglist(Sequence):
         if self.keep_files:
             self.flush()
         else:
-            self.destroy(concurrency=0)
+            self.destroy()
 
     def __getitem__(self, idx: int):  # type: ignore
         '''
@@ -519,7 +521,7 @@ class Biglist(Sequence):
     def append(self, x) -> None:
         self._append(x, concurrent=False)
 
-    def destroy(self, *, concurrency: int = None) -> None:
+    def destroy(self) -> None:
         '''
         Clears all the files and releases all in-memory data held by this object,
         so that the object is as if upon `__init__` with an empty directory pointed to
@@ -532,7 +534,7 @@ class Biglist(Sequence):
         self._read_buffer_file = None
         self._read_buffer_item_range = None
         self._append_buffer = []
-        self.path.rmrf(concurrency=concurrency)
+        self.path.rmrf()
 
     def extend(self, x: Iterable) -> None:
         for v in x:
@@ -805,7 +807,22 @@ class ListView(Sequence):
         return self._list
 
 
+class JsonByteSerializer(ByteSerializer):
+    @classmethod
+    def serialize(cls, x, **kwargs):
+        return json.dumps(x, **kwargs).encode()
+
+    @classmethod
+    def deserialize(cls, y, **kwargs):
+        return _loads(json.loads, y.decode(), **kwargs)
+
+
 Biglist.register_storage_format('json', JsonByteSerializer)
+Biglist.register_storage_format('json-z', ZJsonSerializer)
+Biglist.register_storage_format('json-zstd', ZstdJsonSerializer)
+Biglist.register_storage_format('pickle', PickleSerializer)
+Biglist.register_storage_format('pickle-z', ZPickleSerializer)
+Biglist.register_storage_format('pickle-zstd', ZstdPickleSerializer)
 Biglist.register_storage_format('orjson', OrjsonSerializer)
-Biglist.register_storage_format('pickle-z', CompressedPickleSerializer)
-Biglist.register_storage_format('orjson-z', CompressedOrjsonSerializer)
+Biglist.register_storage_format('orjson-z', ZOrjsonSerializer)
+Biglist.register_storage_format('orjson-zstd', ZstdOrjsonSerializer)
